@@ -186,6 +186,28 @@ pub fn u32_as_usize(n: u32) -> usize {
   n.try_into().expect("here's a nickel, get a better computer")
 }
 
+/// Translate a number into an alphabetic numbering system, indexing into the following infinite
+/// sequence:
+/// ```ignore
+/// a, b, c, ... z, aa, ab, ... az, ba, ... bz, ... zz, aaa, ...
+/// ```
+pub fn alphanumber(n: usize) -> String {
+  let mut out = Vec::with_capacity(2);
+  let mut n = n + 1;
+  while n != 0 {
+    #[allow(clippy::cast_possible_truncation)]
+    {
+      out.push(b'a' + ((n - 1) % 26) as u8);
+    }
+    #[allow(clippy::integer_division)]
+    {
+      n = (n - 1) / 26;
+    }
+  }
+  out.reverse();
+  unsafe { String::from_utf8_unchecked(out) }
+}
+
 /// Extension trait for [`Mutex`](std::sync::Mutex)`<T>`.
 pub trait MutexExt<T> {
   /// Like `lock`, but propagates instead of catches panics.
@@ -324,6 +346,7 @@ impl<T> ArcList<T> {
 }
 
 /// An iterator over an [`ArcList`].
+#[must_use]
 #[derive(Debug, Clone)]
 pub struct ArcListIter<'a, T>(&'a ArcList<T>);
 
@@ -597,7 +620,7 @@ impl<'a> From<&'a FileSpan> for Span {
 /// Try to get memory usage (resident set size) in bytes using the
 /// [`getrusage()`](libc::getrusage) function from libc.
 #[allow(unused)]
-#[cfg(feature = "memory")]
+#[cfg(all(feature = "memory", not(target_arch = "wasm32")))]
 fn get_memory_rusage() -> usize {
   use std::convert::TryInto;
   let usage = unsafe {
@@ -609,6 +632,12 @@ fn get_memory_rusage() -> usize {
   x * 1024
 }
 
+/// Try to get memory usage (resident set size) in bytes using the
+/// [`getrusage()`](libc::getrusage) function from libc.
+#[allow(unused)]
+#[cfg(all(feature = "memory", target_arch = "wasm32"))]
+fn get_memory_rusage() -> usize { 0 }
+
 /// Try to get total memory usage (stack + data) in bytes using the `/proc` filesystem.
 /// Falls back on [`getrusage()`](libc::getrusage) if procfs doesn't exist.
 #[cfg(all(feature = "memory", target_os = "linux"))]
